[−][src]Struct oauth1_request::Builder
A builder for OAuth Authorization header string.
Implementations
impl<'a, SM: SignatureMethod, C: Borrow<str>, T: Borrow<str>> Builder<'a, SM, C, T>[src]
pub fn new(client: Credentials<C>, signature_method: SM) -> Self[src]
Creates a Builder that signs requests using the specified client credentials
and signature method.
pub fn with_token(token: Token<C, T>, signature_method: SM) -> Self[src]
Creates a Builder that uses the token credentials from token.
pub fn token(&mut self, token: impl Into<Option<Credentials<T>>>) -> &mut Self[src]
Sets/unsets the token credentials pair to sign requests with.
pub fn callback(&mut self, callback: impl Into<Option<&'a str>>) -> &mut Self[src]
Sets/unsets the oauth_callback URI.
pub fn verifier(&mut self, verifier: impl Into<Option<&'a str>>) -> &mut Self[src]
Sets/unsets the oauth_verifier value.
pub fn nonce(&mut self, nonce: impl Into<Option<&'a str>>) -> &mut Self[src]
Sets/unsets the oauth_nonce value.
By default, Builder generates a random nonce for each request.
This method overrides that behavior and forces the Builder to use the specified nonce.
This method is for debugging/testing purpose only and should not be used in production.
pub fn timestamp(
&mut self,
timestamp: impl Into<Option<NonZeroU64>>
) -> &mut Self[src]
&mut self,
timestamp: impl Into<Option<NonZeroU64>>
) -> &mut Self
Sets/unsets the oauth_timestamp value.
By default, Builder uses the timestamp of the time when build(-like) method is called.
This method overrides that behavior and forces the Builder to use the specified timestamp.
This method is for debugging/testing purpose only and should not be used in production.
pub fn version(&mut self, version: bool) -> &mut Self[src]
Sets whether to include the oauth_version value in requests.
pub fn get<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a GET request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn put<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a PUT request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn post<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a POST request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn delete<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a DELETE request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn options<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes an OPTIONS request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn head<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a HEAD request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn connect<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a CONNECT request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn patch<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a PATCH request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn trace<U: Display, R: Request + ?Sized>(
&self,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a TRACE request to uri.
uri must not contain a query part, which would result in a wrong signature.
pub fn build<U: Display, R: Request + ?Sized>(
&self,
method: &str,
uri: U,
request: &R
) -> String where
SM: Clone, [src]
&self,
method: &str,
uri: U,
request: &R
) -> String where
SM: Clone,
Authorizes a request to uri with a custom HTTP request method.
uri must not contain a query part, which would result in a wrong signature.
pub fn consume<U: Display, R: Request + ?Sized>(
self,
method: &str,
uri: U,
request: &R
) -> String[src]
self,
method: &str,
uri: U,
request: &R
) -> String
Authorizes a request and consumes self.
This may be more efficient than build if the signature method holds a non-Copy data
(e.g. RSA private key). However, the cost is the same as build for the signature methods
bundled with this library (HmacSha1 and Plaintext).